html {
  background: #ca0ee8 radial-gradient(circle, #ca0ee8 0%, #090000 80%) center center / cover no-repeat;
  color: white;
  font-style: italic;
  text-rendering: optimizeLegibility;
  min-height: 100%;
}

#moztext {
  margin-top: 15%;
  font-size: 1.1em;
  font-family: serif;
  text-align: center;
  line-height: 1.5;
}

#from {
  font-size: 1.95em;
  font-family: serif;
  text-align: end;
}

em {
  font-size: 1.3em;
  line-height: 0;
}

a {
  text-decoration: none;
  color: white;
}
